sendPasswordResetEmail method
Future<void>
sendPasswordResetEmail({
- required String email,
- ActionCodeSettings? actionCodeSettings,
Sends a password reset email to the given email address.
To complete the password reset, call confirmPasswordReset with the code supplied in the email sent to the user, along with the new password specified by the user.
If email enumeration protection is enabled for the Firebase project, this method may complete successfully even when the email does not correspond to an existing user.
May throw a FirebaseAuthException with the following error codes:
- auth/invalid-email
Thrown if the email address is not valid. - auth/missing-android-pkg-name
An Android package name must be provided if the Android app is required to be installed. - auth/missing-continue-uri
A continue URL must be provided in the request. - auth/missing-ios-bundle-id
An iOS Bundle ID must be provided if an App Store ID is provided. - auth/invalid-continue-uri
The continue URL provided in the request is invalid. - auth/unauthorized-continue-uri
The domain of the continue URL is not whitelisted. Whitelist the domain in the Firebase console. - auth/user-not-found
Thrown if there is no user corresponding to the email address. Note: This exception is not thrown when email enumeration protection is enabled.
Implementation
Future<void> sendPasswordResetEmail({
required String email,
ActionCodeSettings? actionCodeSettings,
}) {
return _delegate.sendPasswordResetEmail(email, actionCodeSettings);
}